#
# PySNMP MIB module DS0BUNDLE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DS0BUNDLE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:10:44 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion")
( ifIndex, InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex", "InterfaceIndex")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( ModuleIdentity, Counter64, NotificationType, TimeTicks, Bits, Counter32, IpAddress, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, Integer32, MibIdentifier, Unsigned32, transmission, ObjectIdentity, iso, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "Counter64", "NotificationType", "TimeTicks", "Bits", "Counter32", "IpAddress", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "Integer32", "MibIdentifier", "Unsigned32", "transmission", "ObjectIdentity", "iso")
( TextualConvention, TestAndIncr, RowStatus, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "TestAndIncr", "RowStatus", "DisplayString")
ds0Bundle = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 82)).setRevisions(("1998-05-24 20:10",))
if mibBuilder.loadTexts: ds0Bundle.setLastUpdated('9807161630Z')
if mibBuilder.loadTexts: ds0Bundle.setOrganization('IETF Trunk MIB Working Group')
if mibBuilder.loadTexts: ds0Bundle.setContactInfo('        David Fowler\n\n          Postal: Newbridge Networks Corporation\n                  600 March Road\n                  Kanata, Ontario, Canada K2K 2E6\n\n                  Tel: +1 613 591 3600\n                  Fax: +1 613 599 3619\n\n          E-mail: davef@newbridge.com')
if mibBuilder.loadTexts: ds0Bundle.setDescription('The MIB module to describe\n             DS0 Bundle interfaces objects.')
dsx0BundleNextIndex = MibScalar((1, 3, 6, 1, 2, 1, 10, 82, 2), TestAndIncr()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0BundleNextIndex.setDescription('This object is used to assist the manager in\n               selecting a value for dsx0BundleIndex.  Because\n               this object is of syntax TestAndIncr (see the\n               SNMPv2-TC document, RFC 1903) it can also be used\n               to avoid race conditions with multiple managers\n               trying to create rows in the table.\n\n               If the result of the SET for dsx0BundleNextIndex\n               is not success, this means the value has been\n               changed from index (i.e. another manager used the\n               value), so a new value is required.\n\n               The algorithm is:\n               done = false\n               while done == false\n                   index = GET (dsx0BundleNextIndex.0)\n                   SET (dsx0BundleNextIndex.0=index)\n                   if (set failed)\n                     done = false\n                   else\n                     SET(dsx0BundleRowStatus.index=createAndGo)\n                     if (set failed)\n                       done = false\n                     else\n                       done = true\n                       other error handling')
dsx0BundleTable = MibTable((1, 3, 6, 1, 2, 1, 10, 82, 3), )
if mibBuilder.loadTexts: dsx0BundleTable.setDescription("There is an row in this table for each ds0Bundle\n               in the system.  This table can be used to\n               (indirectly) create rows in the ifTable with\n               ifType = 'ds0Bundle(82)'.")
dsx0BundleEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 82, 3, 1), ).setIndexNames((0, "DS0BUNDLE-MIB", "dsx0BundleIndex"))
if mibBuilder.loadTexts: dsx0BundleEntry.setDescription('There is a row in entry in this table for each\n               ds0Bundle interface.')
dsx0BundleIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647)))
if mibBuilder.loadTexts: dsx0BundleIndex.setDescription('A unique identifier for a ds0Bundle.  This is not\n               the same value as ifIndex.  This table is not\n               indexed by ifIndex because the manager has to\n               choose the index in a createable row and the agent\n               must be allowed to select ifIndex values.')
dsx0BundleIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 3, 1, 2), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0BundleIfIndex.setDescription('The ifIndex value the agent selected for the\n               (new) ds0Bundle interface.')
dsx0BundleCircuitIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 3, 1, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dsx0BundleCircuitIdentifier.setDescription("This variable contains the transmission vendor's\n               circuit identifier, for the purpose of\n               facilitating troubleshooting.")
dsx0BundleRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 3, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dsx0BundleRowStatus.setDescription('This object is used to create and delete rows in\n               this table.')
dsx0BondingTable = MibTable((1, 3, 6, 1, 2, 1, 10, 82, 1), )
if mibBuilder.loadTexts: dsx0BondingTable.setDescription('The DS0 Bonding table.')
dsx0BondingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 82, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: dsx0BondingEntry.setDescription('An entry in the DS0 Bonding table.  There is a\n               row in this table for each DS0Bundle interface.')
dsx0BondMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("none", 1), ("other", 2), ("mode0", 3), ("mode1", 4), ("mode2", 5), ("mode3", 6),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dsx0BondMode.setDescription('This object indicates which BONDing mode is used,\n               if any, for a ds0Bundle.  Mode0 provides parameter\n               and number exchange with no synchronization.  Mode\n               1 provides parameter and number exchange.  Mode 1\n               also provides synchronization during\n               initialization but does not include inband\n               monitoring.  Mode 2 provides all of the above plus\n               inband monitoring.  Mode 2 also steals 1/64th of\n               the bandwidth of each channel (thus not supporting\n               n x 56/64 kbit/s data channels for most values of\n               n). Mode 3 provides all of the above, but also\n               provides n x 56/64 kbit/s data channels.  Most\n               common implementations of Mode 3 add an extra\n               channel to support the inband monitoring overhead.\n               ModeNone should be used when the interface is not\n               performing bandwidth-on-demand.')
dsx0BondStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("idle", 1), ("callSetup", 2), ("dataTransfer", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0BondStatus.setDescription('This object indicates the current status of the\n               bonding call using this ds0Bundle. idle(1) should\n               be used when the bonding mode is set to none(1).')
dsx0BondRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 82, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: dsx0BondRowStatus.setDescription('This object is used to create new rows in this\n               table, modify existing rows, and to delete\n               existing rows.')
ds0BundleConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 82, 4))
ds0BundleGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 82, 4, 1))
ds0BundleCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 82, 4, 2))
ds0BundleCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 82, 4, 2, 1)).setObjects(*(("DS0BUNDLE-MIB", "ds0BundleConfigGroup"), ("DS0BUNDLE-MIB", "ds0BondingGroup"),))
if mibBuilder.loadTexts: ds0BundleCompliance.setDescription('The compliance statement for DS0Bundle\n               interfaces.')
ds0BondingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 82, 4, 1, 1)).setObjects(*(("DS0BUNDLE-MIB", "dsx0BondMode"), ("DS0BUNDLE-MIB", "dsx0BondStatus"), ("DS0BUNDLE-MIB", "dsx0BondRowStatus"),))
if mibBuilder.loadTexts: ds0BondingGroup.setDescription('A collection of objects providing\n                           configuration information applicable\n                           to all DS0 interfaces.')
ds0BundleConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 82, 4, 1, 2)).setObjects(*(("DS0BUNDLE-MIB", "dsx0BundleNextIndex"), ("DS0BUNDLE-MIB", "dsx0BundleIfIndex"), ("DS0BUNDLE-MIB", "dsx0BundleCircuitIdentifier"), ("DS0BUNDLE-MIB", "dsx0BundleRowStatus"),))
if mibBuilder.loadTexts: ds0BundleConfigGroup.setDescription('A collection of objects providing the ability to\n               create a new ds0Bundle in the ifTable as well as\n               configuration information about the ds0Bundle.')
mibBuilder.exportSymbols("DS0BUNDLE-MIB", dsx0BundleRowStatus=dsx0BundleRowStatus, dsx0BondingEntry=dsx0BondingEntry, ds0BundleCompliance=ds0BundleCompliance, dsx0BondRowStatus=dsx0BondRowStatus, PYSNMP_MODULE_ID=ds0Bundle, dsx0BundleNextIndex=dsx0BundleNextIndex, dsx0BondingTable=dsx0BondingTable, ds0BundleConformance=ds0BundleConformance, ds0BundleCompliances=ds0BundleCompliances, ds0BondingGroup=ds0BondingGroup, dsx0BundleIfIndex=dsx0BundleIfIndex, dsx0BundleEntry=dsx0BundleEntry, dsx0BundleCircuitIdentifier=dsx0BundleCircuitIdentifier, dsx0BondStatus=dsx0BondStatus, ds0BundleConfigGroup=ds0BundleConfigGroup, ds0Bundle=ds0Bundle, dsx0BondMode=dsx0BondMode, dsx0BundleIndex=dsx0BundleIndex, ds0BundleGroups=ds0BundleGroups, dsx0BundleTable=dsx0BundleTable)



#
# PySNMP MIB module IANATn3270eTC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANATn3270eTC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:16:11 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsIntersection, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsIntersection", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( ObjectIdentity, TimeTicks, Gauge32, mib_2, experimental, NotificationType, iso, Integer32, Counter32, MibIdentifier, Bits, ModuleIdentity, IpAddress, Counter64, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ObjectIdentity", "TimeTicks", "Gauge32", "mib-2", "experimental", "NotificationType", "iso", "Integer32", "Counter32", "MibIdentifier", "Bits", "ModuleIdentity", "IpAddress", "Counter64", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
ianaTn3270eTcMib = ModuleIdentity((1, 3, 6, 1, 2, 1, 61)).setRevisions(("1998-07-27 00:00",))
if mibBuilder.loadTexts: ianaTn3270eTcMib.setLastUpdated('9807270000Z')
if mibBuilder.loadTexts: ianaTn3270eTcMib.setOrganization('IANA')
if mibBuilder.loadTexts: ianaTn3270eTcMib.setContactInfo('Internet Assigned Numbers Authority\n\n             Postal: USC/Information Sciences Institute\n                     4676 Admiralty Way, Marina del Rey, CA 90292\n\n             Tel:    +1  310 822 1511\n             E-Mail: iana@isi.edu')
if mibBuilder.loadTexts: ianaTn3270eTcMib.setDescription('This module defines a set of textual conventions\n            for use by the TN3270E-MIB and the TN3270E-RT-MIB.\n\n            Any additions or changes to the contents of this\n            MIB module must first be discussed on the tn3270e\n            working group list at: tn3270e@list.nih.gov\n            and approved by one of the following TN3270E\n            working group contacts:\n\n                Ed Bailey (co-chair) - elbailey@us.ibm.com\n                Michael Boe (co-chair) - mboe@cisco.com\n                Ken White - kennethw@vnet.ibm.com\n                Robert Moore - remoore@us.ibm.com\n\n            The above list of contacts can be altered with\n            the approval of the two co-chairs.\n\n            The Textual Conventions defined within this MIB have\n            no security issues associated with them unless\n            explicitly stated in their corresponding\n            DESCRIPTION clause.')
class IANATn3270eAddrType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2,))
    namedValues = NamedValues(("unknown", 0), ("ipv4", 1), ("ipv6", 2),)

class IANATn3270eAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class IANATn3270eClientType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10,))
    namedValues = NamedValues(("none", 1), ("other", 2), ("ipv4", 3), ("ipv6", 4), ("domainName", 5), ("truncDomainName", 6), ("string", 7), ("certificate", 8), ("userId", 9), ("x509dn", 10),)

class IANATn3270Functions(Bits, TextualConvention):
    namedValues = NamedValues(("transmitBinary", 0), ("timemark", 1), ("endOfRecord", 2), ("terminalType", 3), ("tn3270Regime", 4), ("scsCtlCodes", 5), ("dataStreamCtl", 6), ("responses", 7), ("bindImage", 8), ("sysreq", 9),)

class IANATn3270ResourceType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("other", 1), ("terminal", 2), ("printer", 3), ("terminalOrPrinter", 4),)

class IANATn3270DeviceType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 100,))
    namedValues = NamedValues(("ibm3278d2", 1), ("ibm3278d2E", 2), ("ibm3278d3", 3), ("ibm3278d3E", 4), ("ibm3278d4", 5), ("ibm3278d4E", 6), ("ibm3278d5", 7), ("ibm3278d5E", 8), ("ibmDynamic", 9), ("ibm3287d1", 10), ("unknown", 100),)

class IANATn3270eLogData(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(6,2048),)
mibBuilder.exportSymbols("IANATn3270eTC-MIB", IANATn3270eClientType=IANATn3270eClientType, ianaTn3270eTcMib=ianaTn3270eTcMib, IANATn3270ResourceType=IANATn3270ResourceType, IANATn3270eLogData=IANATn3270eLogData, IANATn3270eAddrType=IANATn3270eAddrType, PYSNMP_MODULE_ID=ianaTn3270eTcMib, IANATn3270Functions=IANATn3270Functions, IANATn3270eAddress=IANATn3270eAddress, IANATn3270DeviceType=IANATn3270DeviceType)



#
# PySNMP MIB module PPP-BRIDGE-NCP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/PPP-BRIDGE-NCP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:24:12 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ppp, ) = mibBuilder.importSymbols("PPP-LCP-MIB", "ppp")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Bits, NotificationType, IpAddress, iso, Unsigned32, Counter64, ModuleIdentity, Integer32, Counter32, MibIdentifier, ObjectIdentity, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "NotificationType", "IpAddress", "iso", "Unsigned32", "Counter64", "ModuleIdentity", "Integer32", "Counter32", "MibIdentifier", "ObjectIdentity", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
pppBridge = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 23, 4))
pppBridgeTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 4, 1), )
if mibBuilder.loadTexts: pppBridgeTable.setDescription('Table containing the parameters and statistics\n                         for the local PPP entity that are related to\n                         the operation of Bridging over the PPP.')
pppBridgeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: pppBridgeEntry.setDescription('Bridging information for a particular PPP\n                         link.')
pppBridgeOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("opened", 1), ("not-opened", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeOperStatus.setDescription('The operational status of the Bridge network\n                         protocol. If the value of this object is up\n                         then the finite state machine for the Bridge\n                         network protocol has reached the Opened state.')
pppBridgeLocalToRemoteTinygramCompression = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeLocalToRemoteTinygramCompression.setDescription('Indicates whether the local node will perform\n                         Tinygram Compression when sending packets to\n                         the remote entity. If false then the local\n                         entity will not perform Tinygram Compression.\n                         If true then the local entity will perform\n                         Tinygram Compression. The value of this object\n                         is meaningful only when the link has reached\n                         the open state (pppBridgeOperStatus is\n                         opened).')
pppBridgeRemoteToLocalTinygramCompression = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeRemoteToLocalTinygramCompression.setDescription('If false(1) then the remote entity is not\n                         expected to perform Tinygram Compression. If\n                         true then the remote entity is expected to\n                         perform Tinygram Compression. The value of this\n                         object is meaningful only when the link has\n                         reached the open state (pppBridgeOperStatus is\n                         opened).')
pppBridgeLocalToRemoteLanId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeLocalToRemoteLanId.setDescription('Indicates whether the local node will include\n                         the LAN Identification field in transmitted\n                         packets or not. If false(1) then the local node\n                         will not transmit this field, true(2) means\n                         that the field will be transmitted. The value\n                         of this object is meaningful only when the link\n                         has reached the open state (pppBridgeOperStatus\n                         is opened).')
pppBridgeRemoteToLocalLanId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeRemoteToLocalLanId.setDescription('Indicates whether the remote node has\n                         indicated that it will include the LAN\n                         Identification field in transmitted packets or\n                         not. If false(1) then the field will not be\n                         transmitted, if true(2) then the field will be\n                         transmitted. The value of this object is\n                         meaningful only when the link has reached the\n                         open state (pppBridgeOperStatus is opened).')
pppBridgeConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 4, 2), )
if mibBuilder.loadTexts: pppBridgeConfigTable.setDescription('Table containing the parameters and statistics\n                         for the local PPP entity that are related to\n                         the operation of Bridging over the PPP.')
pppBridgeConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: pppBridgeConfigEntry.setDescription('Bridging Configuration information for a\n                         particular PPP link.')
pppBridgeConfigAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("open", 1), ("close", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeConfigAdminStatus.setDescription("The immediate desired status of the Bridging\n                         network protocol. Setting this object to open\n                         will inject an administrative open event into\n                         the Bridging network protocol's finite state\n                         machine. Setting this object to close will\n                         inject an administrative close event into the\n                         Bridging network protocol's finite state\n                         machine.")
pppBridgeConfigTinygram = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),)).clone('true')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeConfigTinygram.setDescription('If false then the local BNCP entity will not\n                         initiate the Tinygram Compression Option\n                         Negotiation. If true then the local BNCP entity\n                         will initiate negotiation of this option.')
pppBridgeConfigRingId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),)).clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeConfigRingId.setDescription('If false then the local PPP Entity will not\n                         initiate a Remote Ring Identification Option\n                         negotiation. If true then the local PPP entity\n                         will intiate this negotiation. This MIB object\n                         is relevant only if the interface is for 802.5\n                         Token Ring bridging.')
pppBridgeConfigLineId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),)).clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeConfigLineId.setDescription('If false then the local PPP Entity is not to\n                         initiate a Line Identification Option\n                         negotiation. If true then the local PPP entity\n                         will intiate this negotiation. This MIB object\n                         is relevant only if the interface is for 802.5\n                         Token Ring bridging.')
pppBridgeConfigLanId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 2, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("false", 1), ("true", 2),)).clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeConfigLanId.setDescription('If false then the local BNCP entity will not\n                         initiate the LAN Identification Option\n                         Negotiation. If true then the local BNCP entity\n                         will initiate negotiation of this option.')
pppBridgeMediaTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 4, 3), )
if mibBuilder.loadTexts: pppBridgeMediaTable.setDescription('Table identifying which MAC media types are\n                         enabled for the Bridging NCPs.')
pppBridgeMediaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 4, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "PPP-BRIDGE-NCP-MIB", "pppBridgeMediaMacType"))
if mibBuilder.loadTexts: pppBridgeMediaEntry.setDescription('Status of a specific MAC Type for a specific\n                         PPP Link.')
pppBridgeMediaMacType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeMediaMacType.setDescription('The MAC type for which this entry in the\n                         pppBridgeMediaTable is providing status\n                         information. Valid values for this object are\n                         defined in Section 6.6 MAC Type Support\n                         Selection of RFC1220 (Bridging Point-to-Point\n                         Protocol).')
pppBridgeMediaLocalStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 3, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("accept", 1), ("dont-accept", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeMediaLocalStatus.setDescription('Indicates whether the local PPP Bridging\n                         Entity will accept packets of the protocol type\n                         identified in pppBridgeMediaMacType on the PPP\n                         link identified by ifIndex or not. If this\n                         object is accept then any packets of the\n                         indicated MAC type will be received and\n                         properly processed. If this object is dont-\n                         accept then received packets of the indicated\n                         MAC type will not be properly processed.')
pppBridgeMediaRemoteStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 3, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("accept", 1), ("dont-accept", 2),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pppBridgeMediaRemoteStatus.setDescription('Indicates whether the local PPP Bridging\n                         Entity believes that the remote PPP Bridging\n                         Entity will accept packets of the protocol type\n                         identified in pppBridgeMediaMacType on the PPP\n                         link identified by ifIndex or not.')
pppBridgeMediaConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 23, 4, 4), )
if mibBuilder.loadTexts: pppBridgeMediaConfigTable.setDescription('Table identifying which MAC media types are\n                         enabled for the Bridging NCPs.')
pppBridgeMediaConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 23, 4, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "PPP-BRIDGE-NCP-MIB", "pppBridgeMediaConfigMacType"))
if mibBuilder.loadTexts: pppBridgeMediaConfigEntry.setDescription('Status of a specific MAC Type for a specific\n                         PPP Link.')
pppBridgeMediaConfigMacType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 4, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeMediaConfigMacType.setDescription('The MAC type for which this entry in the\n                         pppBridgeMediaConfigTable is providing status\n                         information. Valid values for this object are\n                         defined in Section 6.6 MAC Type Support\n                         Selection of RFC1220 (Bridging Point-to-Point\n                         Protocol).')
pppBridgeMediaConfigLocalStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 23, 4, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("accept", 1), ("dont-accept", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pppBridgeMediaConfigLocalStatus.setDescription('Indicates whether the local PPP Bridging\n                         Entity should accept packets of the protocol\n                         type identified in pppBridgeMediaConfigMacType\n                         on the PPP link identified by ifIndex or not.\n                         Setting this object to the value dont-accept\n                         has the affect of invalidating the\n                         corresponding entry in the\n                         pppBridgeMediaConfigTable object. It is an\n                         implementation-specific matter as to whether\n                         the agent removes an invalidated entry from the\n                         table. Accordingly, management stations must be\n                         prepared to receive tabular information from\n                         agents that corresponds to entries not\n                         currently in use. Changing this object will\n                         have effect when the link is next restarted.')
mibBuilder.exportSymbols("PPP-BRIDGE-NCP-MIB", pppBridgeConfigRingId=pppBridgeConfigRingId, pppBridgeRemoteToLocalLanId=pppBridgeRemoteToLocalLanId, pppBridgeMediaConfigMacType=pppBridgeMediaConfigMacType, pppBridgeMediaEntry=pppBridgeMediaEntry, pppBridgeTable=pppBridgeTable, pppBridgeMediaLocalStatus=pppBridgeMediaLocalStatus, pppBridgeMediaMacType=pppBridgeMediaMacType, pppBridgeConfigAdminStatus=pppBridgeConfigAdminStatus, pppBridgeOperStatus=pppBridgeOperStatus, pppBridgeMediaConfigTable=pppBridgeMediaConfigTable, pppBridgeConfigLineId=pppBridgeConfigLineId, pppBridgeMediaRemoteStatus=pppBridgeMediaRemoteStatus, pppBridgeLocalToRemoteLanId=pppBridgeLocalToRemoteLanId, pppBridgeConfigTable=pppBridgeConfigTable, pppBridgeConfigLanId=pppBridgeConfigLanId, pppBridge=pppBridge, pppBridgeMediaConfigLocalStatus=pppBridgeMediaConfigLocalStatus, pppBridgeMediaConfigEntry=pppBridgeMediaConfigEntry, pppBridgeEntry=pppBridgeEntry, pppBridgeLocalToRemoteTinygramCompression=pppBridgeLocalToRemoteTinygramCompression, pppBridgeRemoteToLocalTinygramCompression=pppBridgeRemoteToLocalTinygramCompression, pppBridgeMediaTable=pppBridgeMediaTable, pppBridgeConfigTinygram=pppBridgeConfigTinygram, pppBridgeConfigEntry=pppBridgeConfigEntry)



#
# PySNMP MIB module HC-ALARM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/HC-ALARM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:14:41 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ConstraintsIntersection, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ConstraintsIntersection", "ValueRangeConstraint", "ValueSizeConstraint")
( CounterBasedGauge64, ) = mibBuilder.importSymbols("HCNUM-TC", "CounterBasedGauge64")
( OwnerString, rmonEventGroup, rmon, ) = mibBuilder.importSymbols("RMON-MIB", "OwnerString", "rmonEventGroup", "rmon")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( IpAddress, ObjectIdentity, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, Bits, TimeTicks, Integer32, iso, Gauge32, Counter32, MibIdentifier, Counter64, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "IpAddress", "ObjectIdentity", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "Bits", "TimeTicks", "Integer32", "iso", "Gauge32", "Counter32", "MibIdentifier", "Counter64", "ModuleIdentity")
( VariablePointer, RowStatus, StorageType, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "VariablePointer", "RowStatus", "StorageType", "TextualConvention", "DisplayString")
hcAlarmMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 16, 29)).setRevisions(("2002-12-16 00:00",))
if mibBuilder.loadTexts: hcAlarmMIB.setLastUpdated('200212160000Z')
if mibBuilder.loadTexts: hcAlarmMIB.setOrganization('IETF RMONMIB Working Group')
if mibBuilder.loadTexts: hcAlarmMIB.setContactInfo('        Andy Bierman\n                     Cisco Systems, Inc.\n                Tel: +1 408 527-3711\n\n             E-mail: abierman@cisco.com\n             Postal: 170 West Tasman Drive\n                     San Jose, CA USA 95134\n\n                     Keith McCloghrie\n                     Cisco Systems, Inc.\n                Tel: +1 408 526-5260\n             E-mail: kzm@cisco.com\n             Postal: 170 West Tasman Drive\n                     San Jose, CA USA 95134\n\n             Send comments to <rmonmib@ietf.org>\n             Mailing list subscription info:\n                 http://www.ietf.org/mailman/listinfo/rmonmib ')
if mibBuilder.loadTexts: hcAlarmMIB.setDescription('This module defines Remote Monitoring MIB extensions for\n             High Capacity Alarms.\n\n             Copyright (C) The Internet Society (2002). This version\n             of this MIB module is part of RFC 3434; see the RFC\n             itself for full legal notices.')
hcAlarmObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 1))
hcAlarmNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 2))
hcAlarmConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 3))
hcAlarmControlObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 1, 1))
hcAlarmCapabilitiesObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 1, 2))
class HcValueStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("valueNotAvailable", 1), ("valuePositive", 2), ("valueNegative", 3),)

hcAlarmTable = MibTable((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1), )
if mibBuilder.loadTexts: hcAlarmTable.setDescription('A list of entries for the configuration of high capacity\n            alarms.')
hcAlarmEntry = MibTableRow((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1), ).setIndexNames((0, "HC-ALARM-MIB", "hcAlarmIndex"))
if mibBuilder.loadTexts: hcAlarmEntry.setDescription('A conceptual row in the hcAlarmTable. Entries are usually\n            created in this table by management application action, but\n            may also be created by agent action as well.')
hcAlarmIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)))
if mibBuilder.loadTexts: hcAlarmIndex.setDescription('An arbitrary integer index value used to uniquely identify\n            this high capacity alarm entry.')
hcAlarmInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmInterval.setDescription('The interval in seconds over which the data is sampled and\n            compared with the rising and falling thresholds.  When\n            setting this variable, care should be taken in the case of\n            deltaValue sampling - the interval should be set short\n            enough that the sampled variable is very unlikely to\n            increase or decrease by more than 2^63 - 1 during a single\n            sampling interval.\n\n\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmVariable = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 3), VariablePointer()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmVariable.setDescription('The object identifier of the particular variable to be\n            sampled.  Only variables that resolve to an ASN.1 primitive\n            type of INTEGER (INTEGER, Integer32, Counter32, Counter64,\n            Gauge, or TimeTicks) may be sampled.\n\n            Because SNMP access control is articulated entirely in terms\n            of the contents of MIB views, no access control mechanism\n            exists that can restrict the value of this object to\n            identify only those objects that exist in a particular MIB\n            view.  Because there is thus no acceptable means of\n            restricting the read access that could be obtained through\n            the alarm mechanism, the probe must only grant write access\n            to this object in those views that have read access to all\n            objects on the probe.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmSampleType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("absoluteValue", 1), ("deltaValue", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmSampleType.setDescription('The method of sampling the selected variable and\n            calculating the value to be compared against the thresholds.\n            If the value of this object is absoluteValue(1), the value\n            of the selected variable will be compared directly with the\n            thresholds at the end of the sampling interval.  If the\n            value of this object is deltaValue(2), the value of the\n            selected variable at the last sample will be subtracted from\n            the current value, and the difference compared with the\n            thresholds.\n\n            If the associated hcAlarmVariable instance could not be\n            obtained at the previous sample interval, then a delta\n\n            sample is not possible, and the value of the associated\n            hcAlarmValueStatus object for this interval will be\n            valueNotAvailable(1).\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmAbsValue = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 5), CounterBasedGauge64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hcAlarmAbsValue.setDescription("The absolute value (i.e., unsigned value) of the\n            hcAlarmVariable statistic during the last sampling period.\n            The value during the current sampling period is not made\n            available until the period is completed.\n\n            To obtain the true value for this sampling interval, the\n            associated instance of hcAlarmValueStatus must be checked,\n            and the value of this object adjusted as necessary.\n\n            If the MIB instance could not be accessed during the\n            sampling interval, then this object will have a value of\n            zero and the associated instance of hcAlarmValueStatus will\n            be set to 'valueNotAvailable(1)'.")
hcAlarmValueStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 6), HcValueStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hcAlarmValueStatus.setDescription('This object indicates the validity and sign of the data for\n            the hcAlarmAbsValue object, as described in the\n            HcValueStatus textual convention.')
hcAlarmStartupAlarm = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("risingAlarm", 1), ("fallingAlarm", 2), ("risingOrFallingAlarm", 3),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmStartupAlarm.setDescription('The alarm that may be sent when this entry is first set to\n\n            active.  If the first sample after this entry becomes active\n            is greater than or equal to the rising threshold and this\n            object is equal to risingAlarm(1) or\n            risingOrFallingAlarm(3), then a single rising alarm will be\n            generated.  If the first sample after this entry becomes\n            valid is less than or equal to the falling threshold and\n            this object is equal to fallingAlarm(2) or\n            risingOrFallingAlarm(3), then a single falling alarm will be\n            generated.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmRisingThreshAbsValueLo = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 8), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmRisingThreshAbsValueLo.setDescription('The lower 32 bits of the absolute value for threshold for\n            the sampled statistic.  The actual threshold value is\n            determined by the associated instances of the\n            hcAlarmRisingThreshAbsValueHi and\n            hcAlarmRisingThresholdValStatus objects, as follows:\n\n               ABS(threshold) = hcAlarmRisingThreshAbsValueLo +\n                     (hcAlarmRisingThreshAbsValueHi * 2^^32)\n\n            The absolute value of the threshold is adjusted as required,\n            as described in the HcValueStatus textual convention.  These\n            three object instances are conceptually combined to\n            represent the rising threshold for this entry.\n\n            When the current sampled value is greater than or equal to\n            this threshold, and the value at the last sampling interval\n            was less than this threshold, a single event will be\n            generated.  A single event will also be generated if the\n            first sample after this entry becomes valid is greater than\n            or equal to this threshold and the associated\n            hcAlarmStartupAlarm is equal to risingAlarm(1) or\n            risingOrFallingAlarm(3).\n\n            After a rising event is generated, another such event will\n            not be generated until the sampled value falls below this\n            threshold and reaches the threshold identified by the\n            hcAlarmFallingThreshAbsValueLo,\n            hcAlarmFallingThreshAbsValueHi, and\n            hcAlarmFallingThresholdValStatus objects.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmRisingThreshAbsValueHi = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 9), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmRisingThreshAbsValueHi.setDescription('The upper 32 bits of the absolute value for threshold for\n            the sampled statistic.  The actual threshold value is\n            determined by the associated instances of the\n            hcAlarmRisingThreshAbsValueLo and\n            hcAlarmRisingThresholdValStatus objects, as follows:\n\n               ABS(threshold) = hcAlarmRisingThreshAbsValueLo +\n                     (hcAlarmRisingThreshAbsValueHi * 2^^32)\n\n            The absolute value of the threshold is adjusted as required,\n            as described in the HcValueStatus textual convention.  These\n            three object instances are conceptually combined to\n            represent the rising threshold for this entry.\n\n            When the current sampled value is greater than or equal to\n            this threshold, and the value at the last sampling interval\n            was less than this threshold, a single event will be\n            generated.  A single event will also be generated if the\n            first sample after this entry becomes valid is greater than\n            or equal to this threshold and the associated\n            hcAlarmStartupAlarm is equal to risingAlarm(1) or\n            risingOrFallingAlarm(3).\n\n            After a rising event is generated, another such event will\n            not be generated until the sampled value falls below this\n            threshold and reaches the threshold identified by the\n            hcAlarmFallingThreshAbsValueLo,\n            hcAlarmFallingThreshAbsValueHi, and\n            hcAlarmFallingThresholdValStatus objects.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmRisingThresholdValStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 10), HcValueStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmRisingThresholdValStatus.setDescription("This object indicates the sign of the data for the rising\n            threshold, as defined by the hcAlarmRisingThresAbsValueLo\n            and hcAlarmRisingThresAbsValueHi objects, as described in\n            the HcValueStatus textual convention.\n\n            The enumeration 'valueNotAvailable(1)' is not allowed, and\n            the associated hcAlarmStatus object cannot be equal to\n            'active(1)' if this object is set to this value.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).")
hcAlarmFallingThreshAbsValueLo = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 11), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmFallingThreshAbsValueLo.setDescription('The lower 32 bits of the absolute value for threshold for\n            the sampled statistic.  The actual threshold value is\n            determined by the associated instances of the\n            hcAlarmFallingThreshAbsValueHi and\n            hcAlarmFallingThresholdValStatus objects, as follows:\n\n               ABS(threshold) = hcAlarmFallingThreshAbsValueLo +\n                     (hcAlarmFallingThreshAbsValueHi * 2^^32)\n\n            The absolute value of the threshold is adjusted as required,\n            as described in the HcValueStatus textual convention.  These\n            three object instances are conceptually combined to\n            represent the falling threshold for this entry.\n\n            When the current sampled value is less than or equal to this\n            threshold, and the value at the last sampling interval was\n            greater than this threshold, a single event will be\n            generated.  A single event will also be generated if the\n            first sample after this entry becomes valid is less than or\n            equal to this threshold and the associated\n            hcAlarmStartupAlarm is equal to fallingAlarm(2) or\n            risingOrFallingAlarm(3).\n\n            After a falling event is generated, another such event will\n            not be generated until the sampled value rises above this\n            threshold and reaches the threshold identified by the\n            hcAlarmRisingThreshAbsValueLo,\n            hcAlarmRisingThreshAbsValueHi, and\n            hcAlarmRisingThresholdValStatus objects.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmFallingThreshAbsValueHi = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 12), Unsigned32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmFallingThreshAbsValueHi.setDescription('The upper 32 bits of the absolute value for threshold for\n            the sampled statistic.  The actual threshold value is\n            determined by the associated instances of the\n            hcAlarmFallingThreshAbsValueLo and\n            hcAlarmFallingThresholdValStatus objects, as follows:\n\n               ABS(threshold) = hcAlarmFallingThreshAbsValueLo +\n                     (hcAlarmFallingThreshAbsValueHi * 2^^32)\n\n            The absolute value of the threshold is adjusted as required,\n            as described in the HcValueStatus textual convention.  These\n            three object instances are conceptually combined to\n            represent the falling threshold for this entry.\n\n            When the current sampled value is less than or equal to this\n            threshold, and the value at the last sampling interval was\n            greater than this threshold, a single event will be\n            generated.  A single event will also be generated if the\n            first sample after this entry becomes valid is less than or\n            equal to this threshold and the associated\n            hcAlarmStartupAlarm is equal to fallingAlarm(2) or\n            risingOrFallingAlarm(3).\n\n            After a falling event is generated, another such event will\n            not be generated until the sampled value rises above this\n            threshold and reaches the threshold identified by the\n            hcAlarmRisingThreshAbsValueLo,\n            hcAlarmRisingThreshAbsValueHi, and\n            hcAlarmRisingThresholdValStatus objects.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmFallingThresholdValStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 13), HcValueStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmFallingThresholdValStatus.setDescription("This object indicates the sign of the data for the falling\n            threshold, as defined by the hcAlarmFallingThreshAbsValueLo\n            and hcAlarmFallingThreshAbsValueHi objects, as described in\n            the HcValueStatus textual convention.\n\n            The enumeration 'valueNotAvailable(1)' is not allowed, and\n            the associated hcAlarmStatus object cannot be equal to\n            'active(1)' if this object is set to this value.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).")
hcAlarmRisingEventIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 14), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmRisingEventIndex.setDescription('The index of the eventEntry that is used when a rising\n            threshold is crossed.  The eventEntry identified by a\n            particular value of this index is the same as identified by\n            the same value of the eventIndex object.  If there is no\n            corresponding entry in the eventTable, then no association\n            exists.  In particular, if this value is zero, no associated\n            event will be generated, as zero is not a valid event index.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmFallingEventIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 15), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmFallingEventIndex.setDescription('The index of the eventEntry that is used when a falling\n            threshold is crossed.  The eventEntry identified by a\n            particular value of this index is the same as identified by\n            the same value of the eventIndex object.  If there is no\n            corresponding entry in the eventTable, then no association\n            exists.  In particular, if this value is zero, no associated\n            event will be generated, as zero is not a valid event index.\n\n            This object may not be modified if the associated\n            hcAlarmStatus object is equal to active(1).')
hcAlarmValueFailedAttempts = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: hcAlarmValueFailedAttempts.setDescription('The number of times the associated hcAlarmVariable instance\n            was polled on behalf of this hcAlarmEntry, (while in the\n            active state) and the value was not available.  This counter\n            may experience a discontinuity if the agent restarts,\n            indicated by the value of sysUpTime.')
hcAlarmOwner = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 17), OwnerString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmOwner.setDescription('The entity that configured this entry and is therefore\n            using the resources assigned to it.')
hcAlarmStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 18), StorageType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmStorageType.setDescription("The type of non-volatile storage configured for this entry.\n            If this object is equal to 'permanent(4)', then the\n            associated hcAlarmRisingEventIndex and\n            hcAlarmFallingEventIndex objects must be writable.")
hcAlarmStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 16, 29, 1, 1, 1, 1, 19), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: hcAlarmStatus.setDescription('The status of this row.\n\n            An entry MUST NOT exist in the active state unless all\n            objects in the entry have an appropriate value, as described\n            in the description clause for each writable object.\n\n            The hcAlarmStatus object may be modified if the associated\n            instance of this object is equal to active(1),\n            notInService(2), or notReady(3).  All other writable objects\n            may be modified if the associated instance of this object is\n            equal to notInService(2) or notReady(3).')
hcAlarmCapabilities = MibScalar((1, 3, 6, 1, 2, 1, 16, 29, 1, 2, 1), Bits().clone(namedValues=NamedValues(("hcAlarmCreation", 0), ("hcAlarmNvStorage", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: hcAlarmCapabilities.setDescription("An indication of the high capacity alarm capabilities\n            supported by this agent.\n\n            If the 'hcAlarmCreation' BIT is set, then this agent allows\n            NMS applications to create entries in the hcAlarmTable.\n\n            If the 'hcAlarmNvStorage' BIT is set, then this agent allows\n            entries in the hcAlarmTable which will be recreated after a\n            system restart, as controlled by the hcAlarmStorageType\n            object.")
hcAlarmNotifPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 2, 0))
hcRisingAlarm = NotificationType((1, 3, 6, 1, 2, 1, 16, 29, 2, 0, 1)).setObjects(*(("HC-ALARM-MIB", "hcAlarmVariable"), ("HC-ALARM-MIB", "hcAlarmSampleType"), ("HC-ALARM-MIB", "hcAlarmAbsValue"), ("HC-ALARM-MIB", "hcAlarmValueStatus"), ("HC-ALARM-MIB", "hcAlarmRisingThreshAbsValueLo"), ("HC-ALARM-MIB", "hcAlarmRisingThreshAbsValueHi"), ("HC-ALARM-MIB", "hcAlarmRisingThresholdValStatus"), ("HC-ALARM-MIB", "hcAlarmRisingEventIndex"),))
if mibBuilder.loadTexts: hcRisingAlarm.setDescription('The SNMP notification that is generated when a high\n            capacity alarm entry crosses its rising threshold and\n            generates an event that is configured for sending SNMP\n            traps.\n\n            The hcAlarmEntry object instances identified in the OBJECTS\n\n            clause are from the entry that causes this notification to\n            be generated.')
hcFallingAlarm = NotificationType((1, 3, 6, 1, 2, 1, 16, 29, 2, 0, 2)).setObjects(*(("HC-ALARM-MIB", "hcAlarmVariable"), ("HC-ALARM-MIB", "hcAlarmSampleType"), ("HC-ALARM-MIB", "hcAlarmAbsValue"), ("HC-ALARM-MIB", "hcAlarmValueStatus"), ("HC-ALARM-MIB", "hcAlarmFallingThreshAbsValueLo"), ("HC-ALARM-MIB", "hcAlarmFallingThreshAbsValueHi"), ("HC-ALARM-MIB", "hcAlarmFallingThresholdValStatus"), ("HC-ALARM-MIB", "hcAlarmFallingEventIndex"),))
if mibBuilder.loadTexts: hcFallingAlarm.setDescription('The SNMP notification that is generated when a high\n            capacity alarm entry crosses its falling threshold and\n            generates an event that is configured for sending SNMP\n            traps.\n\n            The hcAlarmEntry object instances identified in the OBJECTS\n            clause are from the entry that causes this notification to\n            be generated.')
hcAlarmCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 3, 1))
hcAlarmGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 16, 29, 3, 2))
hcAlarmCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 16, 29, 3, 1, 1)).setObjects(*(("HC-ALARM-MIB", "hcAlarmControlGroup"), ("HC-ALARM-MIB", "hcAlarmCapabilitiesGroup"), ("HC-ALARM-MIB", "hcAlarmNotificationsGroup"), ("RMON-MIB", "rmonEventGroup"),))
if mibBuilder.loadTexts: hcAlarmCompliance.setDescription('Describes the requirements for conformance to the High\n            Capacity Alarm MIB.')
hcAlarmControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 29, 3, 2, 1)).setObjects(*(("HC-ALARM-MIB", "hcAlarmInterval"), ("HC-ALARM-MIB", "hcAlarmVariable"), ("HC-ALARM-MIB", "hcAlarmSampleType"), ("HC-ALARM-MIB", "hcAlarmAbsValue"), ("HC-ALARM-MIB", "hcAlarmValueStatus"), ("HC-ALARM-MIB", "hcAlarmStartupAlarm"), ("HC-ALARM-MIB", "hcAlarmRisingThreshAbsValueLo"), ("HC-ALARM-MIB", "hcAlarmRisingThreshAbsValueHi"), ("HC-ALARM-MIB", "hcAlarmRisingThresholdValStatus"), ("HC-ALARM-MIB", "hcAlarmFallingThreshAbsValueLo"), ("HC-ALARM-MIB", "hcAlarmFallingThreshAbsValueHi"), ("HC-ALARM-MIB", "hcAlarmFallingThresholdValStatus"), ("HC-ALARM-MIB", "hcAlarmRisingEventIndex"), ("HC-ALARM-MIB", "hcAlarmFallingEventIndex"), ("HC-ALARM-MIB", "hcAlarmValueFailedAttempts"), ("HC-ALARM-MIB", "hcAlarmOwner"), ("HC-ALARM-MIB", "hcAlarmStorageType"), ("HC-ALARM-MIB", "hcAlarmStatus"),))
if mibBuilder.loadTexts: hcAlarmControlGroup.setDescription('A collection of objects used to configure entries for high\n            capacity alarm threshold monitoring purposes.')
hcAlarmCapabilitiesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 16, 29, 3, 2, 2)).setObjects(*(("HC-ALARM-MIB", "hcAlarmCapabilities"),))
if mibBuilder.loadTexts: hcAlarmCapabilitiesGroup.setDescription("A collection of objects used to indicate an agent's high\n            capacity alarm threshold monitoring capabilities.")
hcAlarmNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 16, 29, 3, 2, 3)).setObjects(*(("HC-ALARM-MIB", "hcRisingAlarm"), ("HC-ALARM-MIB", "hcFallingAlarm"),))
if mibBuilder.loadTexts: hcAlarmNotificationsGroup.setDescription('A collection of notifications to deliver information\n            related to a high capacity rising or falling threshold event\n\n            to a management application.')
mibBuilder.exportSymbols("HC-ALARM-MIB", hcAlarmControlObjects=hcAlarmControlObjects, hcAlarmInterval=hcAlarmInterval, hcAlarmValueStatus=hcAlarmValueStatus, hcAlarmTable=hcAlarmTable, hcAlarmFallingThreshAbsValueLo=hcAlarmFallingThreshAbsValueLo, hcAlarmControlGroup=hcAlarmControlGroup, hcAlarmEntry=hcAlarmEntry, hcAlarmGroups=hcAlarmGroups, hcAlarmAbsValue=hcAlarmAbsValue, hcRisingAlarm=hcRisingAlarm, hcAlarmCompliance=hcAlarmCompliance, hcAlarmSampleType=hcAlarmSampleType, HcValueStatus=HcValueStatus, hcFallingAlarm=hcFallingAlarm, hcAlarmOwner=hcAlarmOwner, hcAlarmStartupAlarm=hcAlarmStartupAlarm, hcAlarmRisingThreshAbsValueHi=hcAlarmRisingThreshAbsValueHi, hcAlarmNotifPrefix=hcAlarmNotifPrefix, hcAlarmFallingThreshAbsValueHi=hcAlarmFallingThreshAbsValueHi, hcAlarmCapabilities=hcAlarmCapabilities, hcAlarmStorageType=hcAlarmStorageType, hcAlarmMIB=hcAlarmMIB, hcAlarmCompliances=hcAlarmCompliances, hcAlarmNotificationsGroup=hcAlarmNotificationsGroup, hcAlarmCapabilitiesObjects=hcAlarmCapabilitiesObjects, hcAlarmNotifications=hcAlarmNotifications, hcAlarmRisingThresholdValStatus=hcAlarmRisingThresholdValStatus, hcAlarmVariable=hcAlarmVariable, hcAlarmStatus=hcAlarmStatus, hcAlarmFallingThresholdValStatus=hcAlarmFallingThresholdValStatus, hcAlarmValueFailedAttempts=hcAlarmValueFailedAttempts, hcAlarmObjects=hcAlarmObjects, hcAlarmConformance=hcAlarmConformance, hcAlarmRisingThreshAbsValueLo=hcAlarmRisingThreshAbsValueLo, hcAlarmRisingEventIndex=hcAlarmRisingEventIndex, hcAlarmCapabilitiesGroup=hcAlarmCapabilitiesGroup, PYSNMP_MODULE_ID=hcAlarmMIB, hcAlarmFallingEventIndex=hcAlarmFallingEventIndex, hcAlarmIndex=hcAlarmIndex)
